.. -*- mode: rst; fill-column: 78; indent-tabs-mode: nil -*-
.. vi: set ft=rst sts=4 ts=4 sw=4 et tw=79:
  ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ###
  #
  #   See COPYING file distributed along with the testkraut package for the
  #   copyright and license terms.
  #
  ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ###

.. _chap_faq:

**************************
Frequently Asked Questions
**************************

Why this name?
  The original aim for this project was to achieve "crowd-sourcing" of software
  testing efforts. "kraut" is obviously almost a semi-homonym of "crowd", while
  at the same time indicating that this software spent its infancy at the
  Institute of Psychology Magdeburg, **Germany**.


